Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Category ¶
type Category struct {
// ID the id of the category
//
// required: true
// min: 1
ID int64 `json:"id"`
// Name the name of the category
//
// required: true
Name string `json:"name"`
}
Category represents a category for a pet categories are things like: cat, dog, fish
Even though this model is not annotated with anything, and it's not included in the initial imports it should still register because it's a required file for the pet model
type EmbeddedColor ¶
type EmbeddedColor interface {
// swagger:name colorName
ColorName() string
}
EmbeddedColor is a color
swagger:model color
type ExtraInfo ¶
type ExtraInfo interface {
// swagger:name extraInfo
ExtraInfo() string
}
ExtraInfo is an interface for things that have extra info swagger:model extra
type NotSelected ¶
type NotSelected struct {
// ID the id of this not selected model
ID int64 `json:"id"`
// Name the name of this not selected model
Name string `json:"name"`
}
NotSelected is a model that is in a transitive package
This model is not annotated and should not be detected for parsing.
type Notable ¶
Notable is a model in a transitive package. it's used for embedding in another model
swagger:model withNotes
type Pet ¶
type Pet struct {
// ID the id of this pet
//
// required: true
ID int64 `json:"id"`
// Name the name of the pet
// this is more like the breed or race of the pet
//
// required: true
// min length: 3
Name string `json:"name"`
// Category the category this pet belongs to.
//
// required: true
Category *Category `json:"category"`
}
Pet represents a pet in our store
this model is not explictly mentioned in the import paths but because it it transitively required by the order it should also be collected.
swagger:model pet
type SomeStringsType ¶
type SomeStringsType []string
SomeStringsType is a type that refines []string
type SomeTimeType ¶
SomeTimeType is a type that refines time.Time swagger:strfmt date-time
type SomeTimedType ¶
SomeTimedType is a type that refines strfmt.DateTime
type SomeTimedsType ¶
SomeTimedsType is a type that refines strfmt.DateTime
type SomeTimesType ¶
SomeTimesType is a type that refines time.Time swagger:strfmt date-time